Changelog
=========

3.x series
----------

.. toctree::
   :maxdepth: 1
   :glob:
   :reversed:

   ./3.0/3*
   ./3.1/3*
   ./3.2/3*


Older series
------------

You can check the changelog of older series in `this page
<pre-history-index>`:ref:.
